==> huaweicloudsdkcodeartsinspector-3.1.127-py2.py3-none-any.whl: huaweicloudsdkcodeartsinspector/v3/model/batch_start_host_tasks_response_body_results.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchStartHostTasksResponseBodyResults:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'scan_id': 'str',
        'host_id': 'str'
    }

    attribute_map = {
        'scan_id': 'scan_id',
        'host_id': 'host_id'
    }

    def __init__(self, scan_id=None, host_id=None):
        """BatchStartHostTasksResponseBodyResults

        The model defined in huaweicloud sdk

        :param scan_id: 扫描ID
        :type scan_id: str
        :param host_id: 主机ID
        :type host_id: str
        """
        
        

        self._scan_id = None
        self._host_id = None
        self.discriminator = None

        if scan_id is not None:
            self.scan_id = scan_id
        if host_id is not None:
            self.host_id = host_id

    @property
    def scan_id(self):
        """Gets the scan_id of this BatchStartHostTasksResponseBodyResults.

        扫描ID

        :return: The scan_id of this BatchStartHostTasksResponseBodyResults.
        :rtype: str
        """
        return self._scan_id

    @scan_id.setter
    def scan_id(self, scan_id):
        """Sets the scan_id of this BatchStartHostTasksResponseBodyResults.

        扫描ID

        :param scan_id: The scan_id of this BatchStartHostTasksResponseBodyResults.
        :type scan_id: str
        """
        self._scan_id = scan_id

    @property
    def host_id(self):
        """Gets the host_id of this BatchStartHostTasksResponseBodyResults.

        主机ID

        :return: The host_id of this BatchStartHostTasksResponseBodyResults.
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        """Sets the host_id of this BatchStartHostTasksResponseBodyResults.

        主机ID

        :param host_id: The host_id of this BatchStartHostTasksResponseBodyResults.
        :type host_id: str
        """
        self._host_id = host_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchStartHostTasksResponseBodyResults):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodeartsinspector-3.1.147-py2.py3-none-any.whl: huaweicloudsdkcodeartsinspector/v3/model/batch_start_host_tasks_response_body_results.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchStartHostTasksResponseBodyResults:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'scan_id': 'str',
        'host_id': 'str'
    }

    attribute_map = {
        'scan_id': 'scan_id',
        'host_id': 'host_id'
    }

    def __init__(self, scan_id=None, host_id=None):
        r"""BatchStartHostTasksResponseBodyResults

        The model defined in huaweicloud sdk

        :param scan_id: 扫描ID
        :type scan_id: str
        :param host_id: 主机ID
        :type host_id: str
        """
        
        

        self._scan_id = None
        self._host_id = None
        self.discriminator = None

        if scan_id is not None:
            self.scan_id = scan_id
        if host_id is not None:
            self.host_id = host_id

    @property
    def scan_id(self):
        r"""Gets the scan_id of this BatchStartHostTasksResponseBodyResults.

        扫描ID

        :return: The scan_id of this BatchStartHostTasksResponseBodyResults.
        :rtype: str
        """
        return self._scan_id

    @scan_id.setter
    def scan_id(self, scan_id):
        r"""Sets the scan_id of this BatchStartHostTasksResponseBodyResults.

        扫描ID

        :param scan_id: The scan_id of this BatchStartHostTasksResponseBodyResults.
        :type scan_id: str
        """
        self._scan_id = scan_id

    @property
    def host_id(self):
        r"""Gets the host_id of this BatchStartHostTasksResponseBodyResults.

        主机ID

        :return: The host_id of this BatchStartHostTasksResponseBodyResults.
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        r"""Sets the host_id of this BatchStartHostTasksResponseBodyResults.

        主机ID

        :param host_id: The host_id of this BatchStartHostTasksResponseBodyResults.
        :type host_id: str
        """
        self._host_id = host_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchStartHostTasksResponseBodyResults):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
